@@ -5,13 +5,11 @@ use 5.010; # for "state"
 
 use Archive::Zip ':ERROR_CODES';
 use Moo 2;
-use XML::Parser;
 use XML::Twig::XPath;
 use Carp qw(croak);
 use List::Util 'max';
-#use Storable 'dclone';
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 our @CARP_NOT = (qw(XML::Twig));
 
 use Filter::signatures;
